#!/usr/bin/env python
# -*- coding: utf-8 -*-
#
# pyDialer - "A simple and handy frontend for WvDial, fork of pyWvDial"
# Copyright (C) 2008 Giacomo Lozito
# Copyright (C) 2009 Aliaksandr Stelmachonak
# Licensed under GNU General Public License v2

# this utility function returns a tuple with two integers (sentbytes/receivedbytes)
# or None if there was a error while retrieving the data from procfs for the interface
def get_sentrecbytes_from_procfs(netif_name):
  try:
    nstf = open('/proc/net/dev', 'r')
  except IOError:
    return None
  nstf.seek(200) # skip the header lines (200 bytes)
  for line in nstf:
    # search for interface named netif_name
    dc = line.find(':')
    if ( dc != -1 ):
      if ( line[:dc].lstrip() == netif_name ):
        st = line[dc+1:].lstrip().split()
        try:
          rx = int(st[0])
          tx = int(st[8])
        except (TypeError, IndexError):
          nstf.close()
          return None
        else:
          nstf.close()
          return (tx, rx)
  nstf.close()
  return None



# this utility function returns a tuple with two integers (sentbytes/receivedbytes)
# or None if there was a error while retrieving the data from sysfs for the interface
def get_sentrecbytes_from_sysfs(netif_name):
  statpath = '/sys/class/net/%s/statistics/' % netif_name
  try:
    rxf = open(statpath + 'rx_bytes', 'r')
  except IOError:
    return None
  rx = rxf.readline()
  if ( rx[-1] == '\n' ):
    rx = rx[:-1]
  rxf.close()
  try:
    txf = open(statpath + 'tx_bytes', 'r')
  except IOError:
    return None
  tx = txf.readline()
  if ( tx[-1] == '\n' ):
    tx = tx[:-1]
  txf.close()
  try:
    rx = int(rx)
    tx = int(tx)
  except TypeError:
    return None
  else:
    return (tx, rx)
